Index: fmts/trunk/p/C0XF2N.m
===================================================================
--- fmts/trunk/p/C0XF2N.m	(revision 1360)
+++ fmts/trunk/p/C0XF2N.m	(revision 1363)
@@ -38,8 +38,8 @@
  S @ZFARY@("C0XTN")=$NA(^C0X(101)) ; TRIPLES GLOBAL NAME
  S @ZFARY@("C0XSN")=$NA(^C0X(201)) ; STRING FILE GLOBAL NAME
- S @ZFARY@("C0XDIR")="/home/glilly/snomed/"
+ S @ZFARY@("C0XDIR")="/home/vista/gpl/C0Q/trunk/rdf/"
  S @ZFARY@("BLKLOAD")=1 ; this file supports block load
  S @ZFARY@("FMTSSTYLE")="F2N" ; fileman style
- S @ZFARY@("REPLYFMT")="JSON"
+ S @ZFARY@("REPLYFMT")=""
  D USEFARY(ZFARY)
  Q
@@ -274,4 +274,6 @@
  S C0XTYPE("owl:ObjectProperty")=1
  S C0XTYPE("owl:Ontology")=1
+ S C0XTYPE("owl:Class")=1
+ S C0XTYPE("rdfs:subClassOf")=1
  S ZI=$O(@ZDOM@(1,"C",""))
  I '$G(C0XTYPE(@ZDOM@(1,"C",ZI))) D  Q  ; not an rdf file
@@ -315,5 +317,5 @@
  . . S ZY=$G(@ZDOM@(ZJ,"A","rdf:resource")) ; potential object
  . . I ZY'="" D  Q ; 
- . . . S C0XOBJ=ZY ; object
+ . . . S C0XOBJ=$$EXT^C0XUTIL(ZY) ; object
  . . . D ADD(ZGRF,C0XSUB,C0XPRE,C0XOBJ) ; finally. our first real triple
  . . ; -- this is an else because of the quit above
@@ -326,4 +328,5 @@
  . . I C0XOBJ="" D  Q  ; not a happy situation
  . . . W !,"ERROR, NO OBJECT FOUND FOR NODE: ",ZJ
+ . . S C0XOBJ=$$EXT^C0XUTIL(C0XOBJ) ; might be namespaced
  . . D ADD(ZGRF,C0XSUB,C0XPRE,C0XOBJ) ; go for it and add a node
  S C0XTRP=$$NOW^XLFDT ; PARSE COMPLETE
Index: fmts/trunk/p/C0XUTIL.m
===================================================================
--- fmts/trunk/p/C0XUTIL.m	(revision 1360)
+++ fmts/trunk/p/C0XUTIL.m	(revision 1363)
@@ -58,4 +58,6 @@
  S C0XVOC("rdfs")="http://www.w3.org/2000/01/rdf-schema#"
  S C0XVOC("vista")="http://osehra.org/ns#"
+ S C0XVOC("vmu")="http://vista.org/mu/"
+ S C0XVOC("vq")="http://vista.org/quality/"
  Q
  ;

Index: fmts/trunk/p/C0XINIT.m
===================================================================
--- fmts/trunk/p/C0XINIT.m	(revision 1360)
+++ fmts/trunk/p/C0XINIT.m	(revision 1363)
@@ -36,5 +36,5 @@
  ; -- we are assuming that FARY is set up properly in C0XF2N
  ; -- with repect to the default directory and the defaut fileman files
  ; -- here's what it is now: "/home/glilly/fmts/trunk/samples/"
  ; -- that means that all the sample files will look like:
  ; --- qds/QDS_0001.rdf
@@ -44,5 +44,5 @@
  D INITFARY^C0XF2N(FARY)
  D USEFARY^C0XF2N(FARY)
- S C0XFARY("C0XDIR")="/home/glilly/fmts/trunk/samples/smart-rdf-in/" ; 
+ S C0XFARY("C0XDIR")="/home/vista/gpl/fmts/trunk/samples/smart-rdf-in/" ; 
  D USEFARY^C0XF2N(FARY)
  S SMART(1)="cole-susan.rdf"
@@ -65,5 +65,5 @@
  . D IMPORT^C0XF2N(SMART(ZI),C0XDIR,,FARY) ; import to the triplestore
  S FARY="C0XFARY"
- S C0XFARY("C0XDIR")="/home/glilly/fmts/trunk/samples/qds/"
+ S C0XFARY("C0XDIR")="/home/vista/gpl/fmts/trunk/samples/qds/"
  D USEFARY^C0XF2N(FARY)
  D IMPORT^C0XF2N("QDS_0001.rdf",C0XDIR,,FARY)
@@ -36,5 +36,5 @@
  ; -- we are assuming that FARY is set up properly in C0XF2N
  ; -- with repect to the default directory and the defaut fileman files
- ; -- here's what it is now: "/home/glilly/fmts/trunk/samples/"
+ ; -- here's what it is now: "/home/vista/gpl/fmts/trunk/samples/"
  ; -- that means that all the sample files will look like:
  ; --- qds/QDS_0001.rdf